@@ -6,10 +6,8 @@
 ##############################################################
 
 
-from .exceltosqlserver import exceltoDBtable
+from .exceltosqlserver import ExcelToDB
 from .exceltosqlserver import hostname
 from .exceltosqlserver import local_ip
 
-
-# from .test_data import writeTest,writeTest1
-# from .tesanother import writeMGS
\ No newline at end of file
+__all__ = ['ExcelToDB', 'hostname', 'local_ip']
\ No newline at end of file
